import axios from 'axios'
import { MessageBox, Message,Notification} from 'element-ui'
import store from '@/store'
import { getToken, getSign } from '@/utils/auth'
import { randomStr20 } from '@/utils/util'
import errorCode from '@/utils/errorCode'
//import md5 from 'js-md5'
//const md5key = "3Jr8S1K18rcC1wAfv8";

axios.defaults.headers['Content-Type'] = 'application/json;charset=utf-8'
// 创建axios实例
const service = axios.create({
  // axios中请求配置有baseURL选项，表示请求URL公共部分
  baseURL: process.env.VUE_APP_BASE_API,
  // 超时
  timeout: 30000
})
// request拦截器
service.interceptors.request.use(config => {

  //// console.log("service.interceptors.request config = ==========================================================="+JSON.stringify(config))

  // 是否需要设置 token
  const isToken = (config.headers || {}).isToken === false
  let timestamp = parseInt(new Date().getTime()), nonce = randomStr20();
  if (getToken() && !isToken) {
    config.headers['Authorization'] = 'Bearer ' + getToken() // 让每个请求携带自定义token 请根据实际情况自行修改
  }
  config.headers['x-zz-timestamp'] = timestamp
  // post请求映射data参数
 // // console.log("config.method = " +config.method +" ,config = "+JSON.stringify(config))
  if (config.method === 'post' || config.method === 'put' || config.method === 'delete') {
    var params = config.data || {};
    //// console.log("config.data == "+JSON.stringify(params))
    //let signStr = JSON.stringify(params) + "nonce" + timestamp + "" + md5key;
    var sign = getSign(params, timestamp);
    var urlParams = config.urlParams || '';
    let url = config.url + '?' + urlParams + 'sign=' + sign + '&nonce=' + nonce;
    config.url = url;
  }
  // get请求映射params参数
  else if (config.method === 'get') {
    var params = config.params || {};
    // let signStr = JSON.stringify(config.params) + "nonce" + timestamp + "" + md5key;
    // var sign = md5(signStr);
    var sign = getSign(params, timestamp)
    //let url = config.url + '?';
    let url = config.url + '?sign=' + sign + '&nonce=' + nonce + '&';
    for (const propName of Object.keys(params)) {
      const value = config.params[propName];
      var part = encodeURIComponent(propName) + "=";
      if (value !== null && typeof(value) !== "undefined") {
        if (typeof value === 'object') {
          for (const key of Object.keys(value)) {
            if (value[key] !== null && typeof (value[key]) !== 'undefined') {
              let params = propName + '[' + key + ']';
              let subPart = encodeURIComponent(params) + '=';
              url += subPart + encodeURIComponent(value[key]) + '&';
            }
          }
        } else {
          url += part + encodeURIComponent(value) + "&";
        }
      }
    }
    url = url.slice(0, -1);
    config.params = {};
    config.url = url;
  }
  return config
}, error => {
    // console.log(error)
    Promise.reject(error)
})

// 响应拦截器
service.interceptors.response.use(res => {
    // 未设置状态码则默认成功状态
    const code = res.data.code || 0;
    // console.log("code == " +code)
    // 获取错误信息
    const msg = errorCode[code] || res.data.msg || errorCode['default']
    if (code === 401) {
      MessageBox.confirm('登录状态已过期，您可以继续留在该页面，或者重新登录', '系统提示', {
          confirmButtonText: '重新登录',
          cancelButtonText: '取消',
          type: 'warning'
        }
      ).then(() => {
        store.dispatch('LogOut').then(() => {
          location.href = '/index';
        })
      }).catch(() => {});
      return Promise.reject('令牌验证失败')
    } else if (code === 500) {
      Message({
        message: msg,
        type: 'error'
      })
      return Promise.reject(new Error(msg))
    } else if (code != 0) {
      // console.log("<<<<<<<<<<<<<<<<<<<<<<<<<<+"+code);
      Message({
        message: msg,
        type: 'error'
      })
      /*
      Message({
        message: msg,
        type: 'error'
      })*/
      return Promise.reject('error')
    } else {
      return res.data
    }
  },
  error => {
    // console.log('err' + error)
    let { message } = error;
    if (message == "Network Error") {
      message = "后端接口连接异常";
    }
    else if (message.includes("timeout")) {
      message = "系统接口请求超时";
    }
    else if (message.includes("Request failed with status code")) {
      message = "系统接口" + message.substr(message.length - 3) + "异常";
    }
    Message({
      message: message,
      type: 'error',
      duration: 5 * 1000
    })
    return Promise.reject(error)
  }
)

export default service
